

TODO_74_03_78_60: Load all dict via `Schema.load(Schema.dump(input_dict))`.

This makes Schema itself populate any defaults and it should also validate the dict.

Maybe add this as part of `TypeDesc` to be by default?

Also, make all plugins do this for their schema in `load_config` function.
